@@ -1,9 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+import random
+import string
+
 from ..util_core.v2ray import restart
 from ..util_core.loader import Loader
 from ..util_core.writer import NodeWriter
-from ..util_core.group import Vmess, Socks, Mtproto, SS, Vless, Trojan, Xtls
+from ..util_core.group import Vmess, Socks, Mtproto, SS, Vless, Trojan
 from ..util_core.selector import GroupSelector, ClientSelector, CommonSelector
 from ..util_core.utils import is_email, clean_iptables, random_email, ColorStr, readchar, random_port, port_is_use, xtls_flow, StreamType
 
@@ -50,7 +53,7 @@ def new_user():
         pass
     else:
         email = ""
-        if type(group.node_list[0]) in (Vmess, Vless, Trojan, Xtls): 
+        if type(group.node_list[0]) in (Vmess, Vless, Trojan): 
             while True:
                 is_duplicate_email=False
                 remail = random_email()
@@ -76,12 +79,13 @@ def new_user():
             nw = NodeWriter(group.tag, group.index)
             info = {'email': email}
             if type(group.node_list[0]) == Trojan:
-                password = input(_("please input trojan user password: "))
+                random_pass = ''.join(random.sample(string.digits + string.ascii_letters, 8))
+                tip = _("create random trojan user password:") + ColorStr.cyan(random_pass) + _(", enter to use or input new password: ")
+                password = input(tip)
                 if password == "":
-                    print(_("password is null!!"))
-                    exit(-1)
+                    password = random_pass
                 info['password'] = password
-            elif type(group.node_list[0]) == Xtls:
+            elif type(group.node_list[0]) == Vless and group.tls == "xtls":
                 flow_list = xtls_flow()
                 print("")
                 flow = CommonSelector(flow_list, _("please select xtls flow type: ")).select()
