@@ -7,7 +7,7 @@ from ..util_core.v2ray import restart, V2ray
 from ..util_core.writer import GroupWriter
 from ..util_core.group import Mtproto, SS
 from ..util_core.selector import GroupSelector
-from ..util_core.utils import get_ip, gen_cert, readchar, is_ipv4
+from ..util_core.utils import get_ip, gen_cert, readchar, is_ipv4, is_email
 
 class TLSModifier:
     def __init__(self, group_tag, group_index, domain='', alpn=None, xtls=False):
@@ -18,13 +18,16 @@ class TLSModifier:
     
     @restart(True)
     def turn_on(self, need_restart=True):
+        cert_list=["letsencrypt", "zerossl", "buypass"]
         print("")
-        print(_("1. Let's Encrypt certificate(auto create, please prepare domain)"))
-        print(_("2. Customize certificate(prepare certificate file paths)"))
+        print(_("1. Let's Encrypt certificate"))
+        print(_("2. ZeroSSL certificate"))
+        print(_("3. BuyPass certificate"))
+        print(_("4. Customize certificate file path"))
         print("")
         choice = readchar(_("please select: "))
-        input_domain = self.domain
-        if choice == "1":
+        input_domain, input_email = self.domain, ""
+        if choice in ("1", "2", "3"):
             if not input_domain:
                 local_ip = get_ip()
                 input_domain = input(_("please input your vps domain: "))
@@ -37,17 +40,27 @@ class TLSModifier:
                     print(_("domain check error!!!"))
                     print("")
                     return
+            
+            if choice in ("2", "3"):
+                while True:
+                    input_email = input(_("please input your email to apply for a certificate: "))
+                    if not input_email:
+                        print("email is null!")
+                        return
+                    elif not is_email(input_email):
+                        print(_("not valid email, please input again!"))
+                        continue
+                    break
 
-            print("")
             print(_("auto generate SSL certificate, please wait.."))
             V2ray.stop()
-            gen_cert(input_domain)
+            gen_cert(input_domain, cert_list[int(choice) - 1], input_email)
             crt_file = "/root/.acme.sh/" + input_domain +"_ecc"+ "/fullchain.cer"
             key_file = "/root/.acme.sh/" + input_domain +"_ecc"+ "/"+ input_domain +".key"
 
             self.writer.write_tls(True, crt_file=crt_file, key_file=key_file, domain=input_domain, alpn=self.alpn, xtls=self.xtls)
 
-        elif choice == "2":
+        elif choice == "4":
             crt_file = input(_("please input certificate cert file path: "))
             key_file = input(_("please input certificate key file path: "))
             if not os.path.exists(crt_file) or not os.path.exists(key_file):
