@@ -88,7 +88,7 @@ def ss_method():
     return ("aes-256-gcm", "aes-128-gcm", "chacha20-poly1305")
 
 def xtls_flow():
-    return ("", "xtls-rprx-origin", "xtls-rprx-direct")
+    return ("xtls-rprx-direct", "xtls-rprx-origin")
 
 def get_ip():
     """
@@ -186,7 +186,7 @@ def bytes_2_human_readable(number_of_bytes, precision=1):
  
     return str(number_of_bytes) + ' ' + unit
 
-def gen_cert(domain):
+def gen_cert(domain, cert_type, email=""):
     local_ip = get_ip()
     service_name = ["nginx", "httpd", "apache2"]
     start_cmd = "systemctl start {}  >/dev/null 2>&1"
@@ -201,11 +201,17 @@ def gen_cert(domain):
             os.system("curl https://get.acme.sh | sh")
 
     open_port(80)
-    if int(os.popen("/root/.acme.sh/acme.sh -v|tr -cd '[0-9]'").read()) >= 300:
-        os.system("/root/.acme.sh/acme.sh --set-default-ca --server letsencrypt")
-    get_ssl_cmd = "bash /root/.acme.sh/acme.sh --issue -d " + domain + " --debug --standalone --keylength ec-256"
+    if int(os.popen("/root/.acme.sh/acme.sh -v|tr -cd '[0-9]'").read()) < 300:
+        os.system("/root/.acme.sh/acme.sh --upgrade")
+    if cert_type in ("buypass", "zerossl"):
+        os.system("bash /root/.acme.sh/acme.sh --server {} --register-account -m {}".format(cert_type, email))
+    get_ssl_cmd = "bash /root/.acme.sh/acme.sh --issue -d " + domain + " --debug --standalone --keylength ec-256 --server " + cert_type
+    if len(os.popen("/root/.acme.sh/acme.sh --list|grep {}|grep -i {}".format(domain, cert_type)).readlines()) == 0:
+        get_ssl_cmd += " --force"
     if ":" in local_ip:
-        get_ssl_cmd = get_ssl_cmd + " --listen-v6"
+        get_ssl_cmd += " --listen-v6"
+    if cert_type == "buypass":
+        get_ssl_cmd += " --days 170"
 
     if not os.path.exists("/.dockerenv"):
         for name in service_name:
@@ -266,23 +272,12 @@ def iptables_open(iptable_way, port):
     os.system(output_cmd.format(iptable_way, "tcp", port))
     os.system(output_cmd.format(iptable_way, "udp", port))
 
-def iptables_startup(iptable_way):
-    if not os.path.exists("/.dockerenv") and not os.path.exists("/etc/profile.d/iptables.sh"):
-        with open('/etc/profile.d/iptables.sh', 'w') as f:
-            f.write(
-'''#!/bin/bash
-[[ -e /root/.iptables ]] && {}-restore -c < /root/.iptables
-'''.format(iptable_way))
-        os.system("chmod +x /etc/profile.d/iptables.sh")
-
 def open_port(openport=-1):
     import platform
     from .loader import Loader
 
     iptable_way = "iptables" if Loader().profile.network == "ipv4" else "ip6tables"
 
-    iptables_startup(iptable_way)
-
     is_centos8 = True if "centos-8" in platform.platform() else False
     firewall_open_cmd = "firewall-cmd --zone=public --add-port={}/tcp --add-port={}/udp --permanent >/dev/null 2>&1"
 
