@@ -79,6 +79,8 @@ class StreamWriter(Writer):
         mtproto_in["tag"] = self.group_tag
         if "allocate" in self.part_json:
             mtproto_in["allocate"] = self.part_json["allocate"]
+        if "sniffing" in self.part_json:
+            mtproto_in["sniffing"] = self.part_json["sniffing"]
         salt = "abcdef" + string.digits
         secret = ''.join([random.choice(salt) for _ in range(32)])
         mtproto_in["settings"]["users"][0]["secret"] = secret
@@ -162,6 +164,8 @@ class StreamWriter(Writer):
         server["inbounds"][0]["settings"]["clients"][0]["id"] = str(uuid.uuid1())
         if "allocate" in self.part_json:
             server["inbounds"][0]["allocate"] = self.part_json["allocate"]
+        if "sniffing" in self.part_json:
+            server["inbounds"][0]["sniffing"] = self.part_json["sniffing"]
         self.part_json = server["inbounds"][0]
         self.config["inbounds"][self.group_index] = self.part_json
 
@@ -201,6 +205,8 @@ class StreamWriter(Writer):
             ss["port"] = self.part_json["port"]
             if "allocate" in self.part_json:
                 ss["allocate"] = self.part_json["allocate"]
+            if "sniffing" in self.part_json:
+                ss["sniffing"] = self.part_json["sniffing"]
             ss["settings"]["method"] = kw["method"]
             ss["settings"]["password"] = kw["password"]
             self.part_json = ss
@@ -324,7 +330,7 @@ class StreamWriter(Writer):
             self.part_json["domain"] = domain
 
         apln_list = (StreamType.VLESS_TLS, StreamType.TROJAN, StreamType.VLESS_XTLS, StreamType.VLESS_GRPC)
-        if "streamSettings" in self.part_json and "alpn" in self.part_json["streamSettings"]["tlsSettings"] and self.stream_type not in apln_list:
+        if self.stream_type not in apln_list and "streamSettings" in self.part_json and "tlsSettings" in self.part_json["streamSettings"] and "alpn" in self.part_json["streamSettings"]["tlsSettings"]:
             del self.part_json["streamSettings"]["tlsSettings"]["alpn"]
 
         self.config["inbounds"][self.group_index] = self.part_json
@@ -424,7 +430,7 @@ class ClientWriter(Writer):
     def __init__(self, group_tag = 'A', group_index = 0, client_index = 0):
         super(ClientWriter, self).__init__(group_tag, group_index)
         self.client_index = client_index
-        self.client_str = "clients" if self.part_json["protocol"] in ("vmess", "vless") else "users"
+        self.client_str = "clients" if self.part_json["protocol"] in ("vmess", "vless", "trojan") else "users"
 
     def write_aid(self, aid = 32):
         self.part_json["settings"][self.client_str][self.client_index]["alterId"] = int(aid)
@@ -553,6 +559,15 @@ class NodeWriter(Writer):
         new_inbound = server["inbounds"][0]
         new_inbound["port"] = int(newPort)
         new_inbound["settings"]["clients"][0]["id"] = str(uuid.uuid1())
+        for rule in self.config["routing"]["rules"]:
+            if "protocol" in rule and "bittorrent" in rule["protocol"]:
+                new_inbound.update({
+                    "sniffing": {
+                        "enabled": True,
+                        "destOverride": ["http", "tls"]
+                    }
+                })
+                break
         self.config["inbounds"].append(new_inbound)
         print(_("add port group success!"))
         self.save()
